@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # encoding: utf-8
-
-from datetime import datetime
+from datetime import datetime as dt
+from datetime import datetime, timedelta
 from email.mime.multipart import MIMEMultipart
 from email.mime.base import MIMEBase
 from email.mime.text import MIMEText
@@ -72,6 +72,7 @@ def fup_or_defup():
         'business_access': {'limit': 50, 'policy': 'business_access_1'},
         'business_plus': {'limit': 150, 'policy': 'business_plus_1'}
     }
+    thirty_days_ago = (dt.today() - timedelta(days=31)).strftime("%Y-%m-%d")
     LOGS.logger.info("Update customers consumption -- START")
     customers_si = core.get_customers_si()
     for customer in customers_si:
@@ -79,11 +80,18 @@ def fup_or_defup():
         data_limit = limits[product]['limit']
         customer_name = customer['name']
         policy = limits[product]['policy']
-        consumption_ko = core.get_consommation_sum(customer_name)
+        consumption_ko = core.get_consommation_sum(customer_name, thirty_days_ago)
         consumption = consumption_ko / 1000000000
         fup_status = consumption > data_limit
         LOGS.logger.info(
-            "consumption: {}/{}Go - fuped: {}".format(consumption, data_limit, fup_status)
+            "{customer} consumption since {date}: {total}/{limit}Go - fuped: {status}"
+            .format(
+                customer=customer_name,
+                date=thirty_days_ago,
+                total=consumption,
+                limit=data_limit,
+                status=fup_status
+            )
         )
         core.update_consommation(product, policy, customer_name, fup_status, consumption)
 
