@@ -71,6 +71,17 @@ def si_database_url():
     )
     return url
 
+def bi_database_url():
+    url = '{eng}://{user}:{password}@{host}:{port}/{name}'.format(
+        eng=CONFIG['BI']['engine'],
+        user=CONFIG['BI']['user'],
+        password=CONFIG['BI']['password'],
+        host=CONFIG['BI']['host'],
+        port=CONFIG['BI']['port'],
+        name=CONFIG['BI']['table_name'],
+    )
+    return url
+
 
 def get_fuped_aiguiller():
     """
@@ -478,25 +489,25 @@ def update_consommation(product, policy, customer_name, fup_status, consumption)
 
 def get_consommation_sum(customer, date):
     """
-    Fetches the last 30days consumptions of a customer
+    Fetches the last 30days consumptions of a customer from BI database
     """
     sql = (
-        "SELECT SUM(octets_in+octets_out) "
-        "FROM cdr "
-        "WHERE customer ilike '%{customer}%' "
-        "AND datetime >= '{date}'::date "  # YYYY-MM-DD
+        "SELECT SUM(octetsin+octetsout) "
+        "FROM all_cdr "
+        "WHERE clientname ilike '%{customer}%' "
+        "AND sessiontime >= '{date}'::date "  # YYYY-MM-DD
         "AND source='internet' "
-        "AND (extract('ISODOW' FROM datetime) between 1 AND 5) "
-        "AND extract(HOUR FROM datetime) < 19 "
-        "AND extract(HOUR FROM datetime) > 8 "
-        "GROUP BY customer;"
+        "AND (extract('ISODOW' FROM sessiontime) between 1 AND 5) "
+        "AND extract(HOUR FROM sessiontime) < 19 "
+        "AND extract(HOUR FROM sessiontime) > 8 "
+        "GROUP BY clientname;"
     ).format(customer=customer, date=date)
     try:
-        with records.Database(si_database_url()) as db:
+        with records.Database(bi_database_url()) as db:
             rows = db.query(sql)
             total = rows.as_dict()
             if total:
-                total = total[0].get('sum', 0)
+                total = float(total[0].get('sum', 0))
             else:
                 total = 0
             LOGS.logger.info(
